// $Id: Application.cpp,v 1.30 2012/11/05 11:41:10 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Application.h"

#include "Config.h"
#include "ConfigurationDialog.h"
#include "FtpCommandDialog.h"
#include "FtpInterface.h"
#include "Icons.h"
#include "IconEngine.h"
#include "LogDialog.h"
#include "MainWindow.h"
#include "QuestionDialog.h"
#include "ScratchFileMonitor.h"
#include "Util.h"
#include "XmlOptions.h"

#include <QtGui/QApplication>

//____________________________________________
void Application::usage( void )
{
    Debug::Throw(0) << "usage : qftp [options] [host]" << endl;
    SERVER::ApplicationManager::commandLineParser().usage();
    return;
}

//____________________________________________
Application::Application( CommandLineArguments arguments ):
    BaseApplication( 0, arguments ),
    Counter( "Application" ),
    mainWindow_( 0 )
{}

//____________________________________________
Application::~Application( void )
{}

//____________________________________________
bool Application::realizeWidget( void )
{
    Debug::Throw( "Application::realizeWidget.\n" );

    // check if the method has already been called.
    if( !BaseApplication::realizeWidget() ) return false;

    // rename about action
    aboutAction().setText( "About Qftp" );
    configurationAction().setText( "Configure Qftp..." );

    // top widget
    mainWindow_ = new MainWindow();
    mainWindow_->setWindowTitle( "Qftp" );

    // scratch files
    scratchFileMonitor_ = new ScratchFileMonitor( this );
    connect( qApp, SIGNAL( aboutToQuit( void ) ), scratchFileMonitor_, SLOT( deleteScratchFiles( void ) ) );
    connect( &mainWindow_->interface(), SIGNAL( scratchFileCreated( const File& ) ), scratchFileMonitor_, SLOT( add( const File& ) ) );
    connect( &mainWindow_->interface(), SIGNAL( busy( void ) ), &mainWindow(), SLOT( busy( void ) ) );
    connect( &mainWindow_->interface(), SIGNAL( ready( void ) ), &mainWindow(), SLOT( idle( void ) ) );

    // load file from arguments or recent files
    QStringList hosts( SERVER::ApplicationManager::commandLineParser( _arguments() ).orphans() );
    if( !hosts.isEmpty() ) mainWindow_->connectToHost( hosts.front() );

    mainWindow_->centerOnDesktop();
    mainWindow_->show();

    emit configurationChanged();

    return true;

}

//___________________________________________________________
void Application::_configuration( void )
{
    Debug::Throw( "Application::_configuration.\n" );
    emit saveConfiguration();
    ConfigurationDialog dialog;
    connect( &dialog, SIGNAL( configurationChanged() ), SIGNAL( configurationChanged() ) );
    dialog.centerOnWidget( qApp->activeWindow() );
    dialog.exec();
}

//________________________________________________
bool Application::_processCommand( SERVER::ServerCommand command )
{

    Debug::Throw( "Application::_processCommand.\n" );
    if( BaseApplication::_processCommand( command ) ) return true;
    if( command.command() == SERVER::ServerCommand::RAISE )
    {
        if( mainWindow_ ) mainWindow_->uniconify();
        QStringList hosts( SERVER::ApplicationManager::commandLineParser( command.arguments() ).orphans() );
        if( !hosts.isEmpty() )
        {

            QString buffer;
            QTextStream( &buffer ) << "Accept requested connection to host \"" << hosts.front() << "\" ?";
            if( QuestionDialog( mainWindow_, buffer ).centerOnParent().exec() )
            { mainWindow_->connectToHost( hosts.front() ); }

        }

        return true;

    } else return false;

}
