#ifndef Application_h
#define Application_h

// $Id: Application.h,v 1.12 2012/11/29 18:42:12 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "Config.h"
#include "Counter.h"

class MainWindow;
class ScratchFileMonitor;

//! Main Window singleton object
class Application: public BaseApplication, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! usage
    static void usage( void );

    //! constructor
    Application( CommandLineArguments );

    //! destructor
    ~Application( void );

    //! create all widgets
    bool realizeWidget( void );

    //! main window
    MainWindow & mainWindow( void ) const
    { return *mainWindow_; }

    //! scratch files
    ScratchFileMonitor& scratchFileMonitor( void ) const
    { return *scratchFileMonitor_; }

    protected slots:

    //! opens MessageBox about Qt version
    void _about( void )
    { BaseApplication::_about( "qftp", VERSION, BUILD_TIMESTAMP ); }

    //! configuration
    void _configuration( void );

    //! process request from application manager
    virtual bool _processCommand( SERVER::ServerCommand );

    private:

    //! main window
    MainWindow *mainWindow_;

    //! scratch files
    ScratchFileMonitor* scratchFileMonitor_;

};

#endif
