// $Id: ConfigurationDialog.cpp,v 1.38 2012/11/22 22:25:33 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "AnimatedTreeView.h"

#include "Application.h"
#include "BaseFileInfoConfigurationWidget.h"
#include "ConfigurationDialog.h"
#include "CustomToolBar.h"
#include "Debug.h"
#include "FileSelectionFrame.h"
#include "GridLayout.h"
#include "BaseIcons.h"
#include "IconEngine.h"
#include "MainWindow.h"
#include "OptionCheckBox.h"
#include "OptionListBox.h"
#include "OptionSpinBox.h"
#include "Singleton.h"
#include "TreeViewConfiguration.h"

#include <QtGui/QGroupBox>
#include <QtGui/QLabel>
#include <QtGui/QPushButton>

//_________________________________________________________
ConfigurationDialog::ConfigurationDialog( QWidget* parent ):
BaseConfigurationDialog( parent )
{

    Debug::Throw( "ConfigurationDialog::ConfigurationDialog.\n" );
    setWindowTitle( "Configuration - Qftp" );

    // base configuration
    baseConfiguration();

    QWidget* page;
    QWidget *box;
    GridLayout* gridLayout;

    // main window
    page = &addPage( IconEngine::get( ICONS::PREFERENCE_APPEARANCE), "Appearance", "Main window appearance" );
    box = new QWidget( page );
    page->layout()->addWidget( box );

    QVBoxLayout* layout = new QVBoxLayout();
    layout->setMargin(0);
    layout->setSpacing(5);
    box->setLayout( layout );

    gridLayout = new GridLayout();
    gridLayout->setSpacing(5);
    gridLayout->setMargin(5);
    gridLayout->setMaxCount(2);
    layout->addLayout( gridLayout );

    // icon view pixmap size
    QLabel* label;
    gridLayout->addWidget( label = new QLabel( "Icon size in icon view:", box ) );
    OptionSpinBox *spinbox = new OptionSpinBox( box, "ICON_VIEW_PIXMAP_SIZE" );
    spinbox->setMinimum( 8 );
    spinbox->setMaximum( 128 );
    spinbox->setSuffix( "px" );
    gridLayout->addWidget( spinbox );
    addOptionWidget( spinbox );
    label->setBuddy( spinbox );

    // prefix
    OptionCheckBox* checkbox;
    layout->addWidget( checkbox = new OptionCheckBox( "Show file system prefix inside location bar", box, "USE_PREFIX" ) );
    addOptionWidget( checkbox );

    // full path
    layout->addWidget( checkbox = new OptionCheckBox( "Show full path inside location bar", box, "USE_TRUNCATION" ) );
    checkbox->setNegative( true );
    addOptionWidget( checkbox );

    // navigation
    layout->addWidget( checkbox = new OptionCheckBox( "Show parent directory icon in file list", box, "SHOW_NAVIGATOR" ) );
    addOptionWidget( checkbox );

    // hidden files
    layout->addWidget( checkbox = new OptionCheckBox( "Show hidden files ", box, "SHOW_HIDDEN_FILES" ) );
    addOptionWidget( checkbox );

    // tooltips
    page = &addPage( IconEngine::get( ICONS::PREFERENCE_APPEARANCE), "Tooltips", "Tooltips appearance" );
    page->layout()->addWidget( checkbox = new OptionCheckBox( "Show tooltips", page, "SHOW_TOOLTIPS" ) );
    addOptionWidget( checkbox );

    QHBoxLayout* hLayout = new QHBoxLayout();
    hLayout->setMargin(5);
    hLayout->setSpacing(5);
    page->layout()->addItem( hLayout );

    BaseFileInfoConfigurationWidget* configurationWidget;
    hLayout->addSpacing( 20 );
    hLayout->addWidget( configurationWidget = new BaseFileInfoConfigurationWidget( page ) );
    configurationWidget->setEnabled( false );
    connect( checkbox, SIGNAL( toggled( bool ) ), configurationWidget, SLOT( setEnabled( bool ) ) );
    addOptionWidget( configurationWidget );

    // external applications
    page = &addPage( IconEngine::get( ICONS::PREFERENCE_FILE_TYPES), "Applications", "Third-party applications" );
    box = new QWidget( page );
    page->layout()->addWidget( box );

    QVBoxLayout* vLayout = new QVBoxLayout();
    vLayout->setSpacing(5);
    vLayout->setMargin(5);
    box->setLayout( vLayout );

    vLayout->addWidget( new QLabel( "List of applications used to open files: ", box ) );

    OptionListBox *listbox = new OptionListBox( box, "APPLICATIONS" );
    listbox->setBrowsable( true );
    listbox->setFileMode( QFileDialog::ExistingFiles );
    listbox->setToolTip( "List of applications used to open files" );
    vLayout->addWidget( listbox );
    addOptionWidget( listbox );

    // load initial configuration
    read();

}
