
// $Id: ConflictDialog.cpp,v 1.13 2012/10/22 11:40:47 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY;  without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA   02111-1307 USA
*
*
*******************************************************************************/

#include "Debug.h"
#include "ConflictDialog.h"
#include "XmlOptions.h"

#include <QtGui/QLabel>

//______________________________________________________________________
ConflictDialog::ConflictDialog( QWidget* parent ):
    FileSelectionDialog( parent, "Following files exists both locally and remotely.\n"
    "Decide which action is to be taken for transfer. " )
{

    Debug::Throw( "ConflictDialog::ConflictDialog.\n" );

    setOptionName( "Conflict_DIALOG" );

    // skip
    _workLayout().addWidget( skipButton_ = new QPushButton( "&Skip", &_mainWidget() ) );
    skipButton_->setToolTip( "Skip selected files from transfer" );
    connect( skipButton_, SIGNAL( clicked() ), this, SLOT( _skip() ) );

    // overwrite
    _workLayout().addWidget( overwriteButton_ = new QPushButton( "&Overwrite", &_mainWidget() ) );
    overwriteButton_->setToolTip( "Overwrite selected files" );
    connect( overwriteButton_, SIGNAL( clicked() ), this, SLOT( _overwrite() ) );

    // adjust list mask
    _list().setMask( _list().mask()|(1<<FileInfoModel::ACTION) );

}

//____________________________________________________________________
void ConflictDialog::_updateButtons( void )
{
    Debug::Throw( "ConflictDialog::_updateButtons.\n" );
    FileSelectionDialog::_updateButtons();

    bool has_selection( !_list().selectionModel()->selectedRows().empty() );
    skipButton_->setEnabled( has_selection );
    overwriteButton_->setEnabled( has_selection );
}

//____________________________________________________________________
void ConflictDialog::_skip( void )
{

    Debug::Throw( "ConflictDialog::_skip.\n" );

    // retrieve selected items, change action
    FileInfo::List selection( selectedFiles() );
    for( FileInfo::List::iterator iter = selection.begin(); iter != selection.end(); ++iter )
    { iter->setStatus( FileInfo::Overwrite, false ); }

    // update model
    _model().add( selection );

    _list().resizeColumnToContents( FileInfoModel::ACTION );

}

//____________________________________________________________________
void ConflictDialog::_overwrite( void )
{

    Debug::Throw( "ConflictDialog::_overwrite.\n" );

    // retrieve selected items, change action
    FileInfo::List selection( selectedFiles() );
    for( FileInfo::List::iterator iter = selection.begin(); iter != selection.end(); ++iter )
    { iter->setStatus( FileInfo::Overwrite, true ); }

    // update model
    _model().add( selection );
    _list().resizeColumnToContents( FileInfoModel::ACTION );

}
