// $Id: ConnectionAttributes.cpp,v 1.12 2012/12/06 16:18:41 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "ConnectionAttributes.h"

#include "Debug.h"
#include "FileInfo.h"
#include "Str.h"
#include "XmlDef.h"
#include "XmlOptions.h"

//_______________________________________________________________________
ConnectionAttributes::ConnectionAttributes( void ):
    Counter( "ConnectionAttributes" ),
    port_( 21 ),
    default_( false )
{ Debug::Throw( "ConnectionAttributes::ConnectionAttributes (empty).\n" ); }

//_______________________________________________________________________
ConnectionAttributes::ConnectionAttributes( const QDomElement& element ):
    Counter( "ConnectionAttributes" ),
    port_( 21 ),
    default_( false )
{

    Debug::Throw( "ConnectionAttributes::ConnectionAttributes.\n" );
    bool savePasswords = XmlOptions::get().get<bool>("SAVE_PASSWORDS");

    // parse attributes
    QDomNamedNodeMap attributes( element.attributes() );
    for( unsigned int i=0; i<attributes.length(); i++ )
    {

        QDomAttr attribute( attributes.item( i ).toAttr() );
        if( attribute.isNull() ) continue;
        QString name( attribute.name() );
        QString value( attribute.value() );

        if( name == XML::NAME ) setName( value );
        else if( name == XML::HOST ) setHost( value );
        else if( name == XML::PORT ) setPort( value.toInt() );
        else if( name == XML::USER ) setUser( value );
        else if( name == XML::PASSWORD ) { if( savePasswords ) setPassword( value ); }
        else if( name == XML::DEFAULT ) setIsDefault( value.toInt() );
        else Debug::Throw(0) << "ConnectionAttributes::ConnectionAttributes - unrecognized name " << name << endl;

    }

    Debug::Throw( "ConnectionAttributes::ConnectionAttributes - done.\n" );

}

//___________________________________________
QDomElement ConnectionAttributes::domElement( QDomDocument& parent ) const
{
    Debug::Throw( "ConnectionAttributes::DomElement.\n");
    QDomElement out( parent.createElement( XML::CONNECTION ) );

    // attributes
    bool savePasswords = XmlOptions::get().get<bool>("SAVE_PASSWORDS");
    out.setAttribute( XML::NAME, name() );
    out.setAttribute( XML::HOST, host() );
    out.setAttribute( XML::PORT, Str().assign<unsigned int>( port() ) );
    out.setAttribute( XML::USER, user() );
    if( savePasswords ) out.setAttribute( XML::PASSWORD, password() );
    out.setAttribute( XML::DEFAULT, QString().setNum( isDefault() ) );
    return out;

}
