#ifndef ConnectionDialog_h
#define ConnectionDialog_h

// $Id: ConnectionDialog.h,v 1.20 2012/09/03 14:21:18 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY;  without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA   02111-1307 USA
*
*******************************************************************************/

#include "BaseDialog.h"
#include "ConnectionAttributes.h"
#include "ConnectionParser.h"
#include "Counter.h"
#include "ListModel.h"

#include <QtGui/QPushButton>
#include <QtGui/QCloseEvent>

class ConnectionFrame;
class TreeView;

//! handles list of connection attributes
class ConnectionDialog: public BaseDialog, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    ConnectionDialog( QWidget* );

    //! destructor
    virtual ~ConnectionDialog( void )
    {}

    //! connection frame
    ConnectionFrame& frame( void ) const
    { return *frame_; }

    protected:

    //! close
    virtual void closeEvent( QCloseEvent* );

    //! load connections from parser
    void _load( void );

    protected slots:

    //! save settings
    void _select( void );

    //! save settings
    void _save( void );

    //! remove settings
    void _remove( void );

    //! connect
    void _connect( void );

    //! toggle save password
    void _toggleSavePasswords( bool state );

    //! cancel
    void _cancel( void );

    //! update buttons
    void _updateButtons( void );

    private:

    //! connection model
    class Model: public ListModel<ConnectionAttributes>, public Counter
    {

        public:

        //! number of columns
        enum { nColumns = 4 };

        //! column types
        enum ColumnTypes {
            NAME,
            HOST,
            PORT,
            USER
        };

        //! constructor
        Model( QObject* = 0 );

        //! data
        virtual QVariant data(const QModelIndex&, int) const;

        //! header data
        virtual QVariant headerData(int, Qt::Orientation, int = Qt::DisplayRole) const;

        //! number of columns for a given index
        virtual int columnCount(const QModelIndex& = QModelIndex()) const
        { return nColumns; }

        protected:

        //! sort
        virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder )
        {}

        private:

        //! list column names
        static const QString columnTitles_[nColumns];

        //! icon
        QIcon icon_;

    };

    //! model
    Model model_;

    //! list
    TreeView* list_;

    //! connection parser
    ConnectionParser parser_;

    //! connection frame
    ConnectionFrame* frame_;

    //!@name buttons
    //@{

    //! save
    QPushButton* saveButton_;

    //! remove
    QPushButton* removeButton_;

    //! connect
    QPushButton* connectButton_;

    //@}

};

#endif
