// $Id: ConnectionParser.cpp,v 1.15 2012/12/20 15:53:17 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "ConnectionParser.h"
#include "XmlDocument.h"

#include <QtCore/QFile>

//_____________________________________________________________________
bool ConnectionParser::read( const File& file )
{
    Debug::Throw( "ConnectionParser::Read.\n" );
    attributes_.clear();

    // check input file
    if( !file.exists() ) return false;

    // parse the file
    XmlDocument document;
    {
        QFile qfile( file );
        if ( !document.setContent( &qfile ) )
        {
            Debug::Throw() << document.error() << endl;
            return false;
        }
    }

    // look for relevant element
    QDomNodeList topNodes = document.elementsByTagName( XML::CONNECTION_LIST );
    if( topNodes.isEmpty() ) return false;

    for(QDomNode node = topNodes.at(0).firstChild(); !node.isNull(); node = node.nextSibling() )
    {
        QDomElement element = node.toElement();
        if( element.isNull() ) continue;

        const QString tagName( element.tagName() );
        if( tagName == XML::CONNECTION ) add( ConnectionAttributes( element ), false );

    }

    // sort
    std::sort( attributes_.begin(), attributes_.end() );

    return true;
}

//_____________________________________________________________________
bool ConnectionParser::write( const File& file )
{
    Debug::Throw( "ConnectionParser::Write.\n" );

     if( file.isEmpty() ) return false;

    // create document and read
    XmlDocument document;
    {
        QFile qtfile( file );
        document.setContent( &qtfile );
    }

    QDomElement top = document.createElement( XML::CONNECTION_LIST );
    foreach( const ConnectionAttributes& attributes, attributes_ )
    { top.appendChild( attributes.domElement( document ) ); }

    // append top node to document and write
    document.replaceChild( top );
    {
        QFile qfile( file );
        if( !qfile.open( QIODevice::WriteOnly ) ) return false;
        qfile.write( document.toByteArray() );
    }

    return true;

}

//_____________________________________________________________________
void ConnectionParser::add( const ConnectionAttributes& attributes, const bool& sort )
{
    ConnectionAttributes::List::iterator iter = std::find_if( attributes_.begin(), attributes_.end(), SameAttributesFTor( attributes ) );
    if( iter == attributes_.end() ) attributes_ << attributes;
    else {

        iter->setPassword( attributes.password() );
        if( *iter < attributes ) iter->setName( attributes.name() );
    }

    if( sort ) std::sort( attributes_.begin(), attributes_.end() );

}

