#ifndef DefaultOptions_h
#define DefaultOptions_h

// $Id: DefaultOptions.h,v 1.28 2012/12/08 20:12:01 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA	02111-1307 USA
*
*
*******************************************************************************/

#include "FileInfoModel.h"
#include "FileSelectionFrame.h"
#include "FtpCommandModel.h"
#include "Util.h"
#include "XmlOptions.h"

//_____________________________________________________
//! default options installer
void installDefaultOptions( void )
{

    // set options default values
    XmlOptions::get().setAutoDefault( true );
    XmlOptions::get().keep( "APPLICATIONS" );
    XmlOptions::get().set( "ICON_PIXMAP", Option( ":/icon.png" , "application icon") );

    // customize pixmap path
    XmlOptions::get().keep( "PIXMAP_PATH" );
    XmlOptions::get().add( "PIXMAP_PATH", ":/pixmaps/128x128" );
    XmlOptions::get().add( "PIXMAP_PATH", ":/pixmaps/48x48" );

    XmlOptions::get().set( "DB_SIZE", "30" );
    XmlOptions::get().set( "MAIN_WINDOW_HEIGHT", "500" );
    XmlOptions::get().set( "MAIN_WINDOW_WIDTH", "700" );

    XmlOptions::get().set( "SHOW_COMMAND_LIST", "0" );
    XmlOptions::get().set( "SHOW_LOG", "0" );
    XmlOptions::get().set( "SHOW_TOOLTIPS", "0" );
    XmlOptions::get().set( "SHOW_HIDDEN_FILES", "0" );

    XmlOptions::get().set( "SAVE_PASSWORDS", Option( "0", "save passwords" ) );
    XmlOptions::get().set( "DEFAULT_PORT", Option( "21", "default login port" ) );

    XmlOptions::get().set( "USE_PREFIX", "1" );
    XmlOptions::get().set( "USE_TRUNCATION", "1" );
    XmlOptions::get().set( "SHOW_NAVIGATOR", "1" );

    // list mask
    XmlOptions::get().set<unsigned int>( "REMOTE_VIEW_MODE", (1<<FileInfoModel::FILE) | (1<<FileInfoModel::SIZE) );
    XmlOptions::get().set<unsigned int>( "REMOTE_LIST_MASK", (1<<FileInfoModel::FILE) | (1<<FileInfoModel::SIZE) );
    XmlOptions::get().set<unsigned int>( "LOCAL_LIST_SORT_ORDER", 0 );
    XmlOptions::get().set<unsigned int>( "REMOTE_LIST_SORT_ORDER", 0 );

    // command list
    XmlOptions::get().set( "FTP_COMMAND_LIST_MASK", Option().set<int>( 1<<FtpCommandModel::NAME ) );

    // view mode
    XmlOptions::get().set<unsigned int>( "LOCAL_VIEW_MODE", FileSelectionFrame::ICONS );
    XmlOptions::get().set<unsigned int>( "REMOTE_VIEW_MODE", FileSelectionFrame::ICONS );

    // pixmap size
    XmlOptions::get().set( "ICON_VIEW_PIXMAP_SIZE", 48 );

    // application name
    XmlOptions::get().set( "APP_NAME", Option( "QFTP", Option::None ) );

    // database file
    XmlOptions::get().set( "HELP_FILE", Option( File( "/.qftp_help" ).addPath( Util::home() ), Option::None ) );
    XmlOptions::get().set( "RC_FILE", Option( File(".qftprc").addPath( Util::home() ), Option::None ) );
    XmlOptions::get().setAutoDefault( false );

};

#endif
