#ifndef FileSelectionDialog_h
#define FileSelectionDialog_h

// $Id: FileSelectionDialog.h,v 1.20 2012/09/18 16:28:17 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY;  without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA   02111-1307 USA
*
*
*******************************************************************************/

#include "QuestionDialog.h"
#include "FileInfo.h"
#include "FileInfoModel.h"
#include "TreeView.h"

#include <QtGui/QPushButton>
#include <QtGui/QLayout>

//! handles FileInfo conflicts
class FileSelectionDialog: public QuestionDialog
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    FileSelectionDialog( QWidget* parent, const QString& label = "" );

    //! destructor
    virtual ~FileSelectionDialog( void )
    {}

    //! set file info list
    virtual void setFiles( const File& local_path, const File& remote_path, const FileInfo::List& files );

    //! update files from list items
    virtual void updateFiles( FileInfo::List& files );

    //! retrieve selected files
    FileInfo::List selectedFiles( void ) const
    { return _model().get( _list().selectionModel()->selectedRows() ); }

    protected slots:

    //! update button states
    virtual void _updateButtons( void );

    protected:

    //! list
    TreeView& _list() const
    { return *list_; }

    //! model
    const FileInfoModel& _model( void ) const
    { return model_; }

    //! model
    FileInfoModel& _model( void )
    { return model_; }

    //! main widget
    QWidget& _mainWidget( void ) const
    { return *mainWidget_; }

    //! main layout
    QVBoxLayout& _mainLayout( void ) const
    { return *mainLayout_; }

    //! work area
    QVBoxLayout& _workLayout( void ) const
    { return *work_; }

    private:

    //! local path
    File localPath_;

    //! remote path
    File remotePath_;

    //! model
    FileInfoModel model_;

    //! main widget
    QWidget* mainWidget_;

    //! list
    TreeView* list_;

    //! work layout
    QVBoxLayout *mainLayout_;

    //! work layout (to add options
    QVBoxLayout *work_;

    //! clear selection button
    QPushButton* clearSelectionButton_;

};

#endif
