// $Id: FtpCommandDialog.cpp,v 1.9 2012/10/11 16:48:13 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "FtpCommandDialog.h"

#include "ColumnSelectionMenu.h"
#include "ColumnSortingMenu.h"
#include "ContextMenu.h"
#include "Icons.h"
#include "IconEngine.h"
#include "TreeView.h"

#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QLayout>
#include <QtGui/QShortcut>
#include <QtGui/QSplitter>

//____________________________________________________________
FtpCommandDialog::FtpCommandDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton )
{

    Debug::Throw( "FtpCommandDialog::FtpCommandDialog.\n" );
    setWindowTitle( "Commands - Qftp" );
    setOptionName( "FTP_COMMAND_DIALOG" );

    // custom margins
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    QSplitter* splitter;
    mainLayout().addWidget( splitter = new QSplitter( this ) );
    splitter->setOrientation( Qt::Vertical );

    // macros
    {
        QWidget* container = new QWidget();
        splitter->addWidget( container );

        container->setLayout( new QVBoxLayout() );
        container->layout()->setMargin(0);
        container->layout()->setSpacing(2);
        container->layout()->addWidget( new QLabel( " Macros:", container ) );
        container->layout()->addWidget( macroList_ = new TreeView(container) );

        macroList_->header()->hide();
        macroList_->setSortingEnabled( true );
        macroList_->setModel( &macroModel_ );
        macroList_->setOptionName( "FTP_MACRO_LIST" );

        // context menu
        QMenu* menu( new ContextMenu( macroList_ ) );
        menu->addMenu( new ColumnSortingMenu( menu, macroList_ ) );
        menu->addMenu( new ColumnSelectionMenu( menu, macroList_ ) );
    }

    // commands
    {
        QWidget* container = new QWidget();
        splitter->addWidget( container );

        container->setLayout( new QVBoxLayout() );
        container->layout()->setMargin(0);
        container->layout()->setSpacing(2);
        container->layout()->addWidget( new QLabel( " Commands:", container ) );
        container->layout()->addWidget( commandList_ = new TreeView(container) );

        commandList_->header()->hide();
        commandList_->setSortingEnabled( true );
        commandList_->setModel( &commandModel_ );
        commandList_->setOptionName( "FTP_COMMAND_LIST" );

        // context menu
        QMenu* menu( new ContextMenu( commandList_ ) );
        menu->addMenu( new ColumnSortingMenu( menu, commandList_ ) );
        menu->addMenu( new ColumnSelectionMenu( menu, commandList_ ) );

    }

    // ok button
    connect( &okButton(), SIGNAL( pressed( void ) ), SLOT( close( void ) ) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT( close() ) );

}

//_____________________________________________________________
void FtpCommandDialog::closeEvent( QCloseEvent* event )
{
    Debug::Throw( "FtpCommandDialog::closeEvent.\n" );
    emit dialogHidden();
    return CustomDialog::closeEvent( event );
}
