// $Id: FtpCommandModel.cpp,v 1.34 2012/11/22 22:25:33 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "FtpCommandModel.h"

#include "Icons.h"
#include "IconEngine.h"
#include "Singleton.h"
#include "TimeStamp.h"
#include "XmlOptions.h"

#include <QtGui/QIcon>

//_______________________________________________
FtpCommandModel::IconCache& FtpCommandModel::_icons()
{
    static IconCache cache;
    return cache;
}

//_______________________________________________
const QString FtpCommandModel::columnTitles_[ FtpCommandModel::nColumns ] =
{
    "Command",
    "File"
};

//_______________________________________________________________
FtpCommandModel::FtpCommandModel( QObject* parent ):
    ListModel<FtpCommand>( parent ),
    Counter( "FtpCommandModel" )
{

    Debug::Throw( "FtpCommandModel::FtpCommandModel.\n" );
    connect( Singleton::get().application(), SIGNAL( configurationChanged() ), SLOT( _updateConfiguration() ) );
    _updateConfiguration();

}

//__________________________________________________________________
QVariant FtpCommandModel::data( const QModelIndex& index, int role ) const
{

    // check index, role and column
    if( !index.isValid() ) return QVariant();

    // retrieve associated command
    const FtpCommand& command( get()[index.row()] );

    // return text associated to command and column
    if( role == Qt::DisplayRole ) {

        switch( index.column() )
        {
            case NAME: return command.name();
            case FILE: return command.argumentCount() > 0  ? command.argument(0).file():QVariant();

            default:
            return QVariant();
        }
    }

    // return icon associated to file
    if( role == Qt::DecorationRole && index.column() == NAME )
    { return _icons()[command.type()]; }

    return QVariant();

}

//__________________________________________________________________
QVariant FtpCommandModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}

//_________________________________________________________
void FtpCommandModel::_updateConfiguration( void )
{

    Debug::Throw( "FtpCommandModel::_updateConfiguration.\n" );

    // install pixmaps
    _icons().clear();
    _installIcons();

    reset();

}

//_____________________________________________________________________
void FtpCommandModel::_installIcons( void ) const
{

    Debug::Throw( "FtpCommandModel::_installIcons" );

    if( !_icons().empty() ) return;

    // type icons
    typedef QHash< FtpCommand::Type, QString > IconNames;
    IconNames typeNames;

    // local icons
    typeNames[FtpCommand::CreateDirectory] = ICONS::CREATE_DIRECTORY;
    typeNames[FtpCommand::ChangeDirectory] = ICONS::OPEN;
    typeNames[FtpCommand::ShowDirectory] = ICONS::FIND;
    typeNames[FtpCommand::Remove] = ICONS::DELETE;
    typeNames[FtpCommand::Copy] = ICONS::PASTE;
    typeNames[FtpCommand::Login] = ICONS::CONNECT;
    typeNames[FtpCommand::ConnectToHost] = ICONS::CONNECT;
    typeNames[FtpCommand::Close] = ICONS::DISCONNECT;
    typeNames[FtpCommand::Rename] = ICONS::RENAME;

    // load link pixmap
    for( IconNames::iterator iter = typeNames.begin(); iter != typeNames.end(); ++iter )
    { _icons().insert( iter.key(), IconEngine::get( iter.value() ) ); }

    return;
}
