#ifndef FtpCommandModel_h
#define FtpCommandModel_h

// $Id: FtpCommandModel.h,v 1.17 2012/10/31 14:55:42 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "ListModel.h"
#include "FtpCommand.h"

#include <QtCore/QHash>

//! Job model. Stores job information for display in lists
class FtpCommandModel : public ListModel<FtpCommand>, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    FtpCommandModel( QObject* = 0 );

    //! destructor
    virtual ~FtpCommandModel()
    {}

    //! number of columns
    enum { nColumns = 2 };

    //! column type enumeration
    enum ColumnType
    {
        NAME,
        FILE
    };

    //!@name methods reimplemented from base class
    //@{

    //! data
    virtual QVariant data( const QModelIndex&, int ) const;

    //! header data
    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;

    //! number of columns for a given index
    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
    { return nColumns; }

    //@}

    public slots:

    //! add command
    virtual void add( const FtpCommand& command )
    { ListModel<FtpCommand>::add( command ); }

    //! add commands
    virtual void add( const FtpCommand::List& commands )
    { ListModel<FtpCommand>::add( commands ); }

    //! remove
    virtual void remove( const FtpCommand& command )
    { ListModel<FtpCommand>::remove( command ); }

    protected:

    //! sort
    virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder )
    {}

    private slots:

    //! update configuration
    void _updateConfiguration( void );

    private:

    //! install pixmaps
    void _installIcons( void ) const;

    //! list column names
    static const QString columnTitles_[nColumns];

    //! icon cache
    typedef QHash<FtpCommand::Type, QIcon> IconCache;

    //! type icon cache for local modifications
    static IconCache& _icons();

};

#endif
