#ifndef FtpMacroModel_h
#define FtpMacroModel_h

// $Id: FtpMacroModel.h,v 1.1 2012/10/11 16:48:13 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "ListModel.h"
#include "FtpMacro.h"

#include <QtCore/QHash>

//! Job model. Stores job information for display in lists
class FtpMacroModel : public ListModel<FtpMacro>, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    FtpMacroModel(QObject *parent = 0);

    //! destructor
    virtual ~FtpMacroModel()
    {}

    //! number of columns
    enum { nColumns = 3 };

    //! column type enumeration
    enum ColumnType { ID, NAME, FILE };

    //!@name methods reimplemented from base class
    //@{

    //! data
    virtual QVariant data(const QModelIndex &index, int role) const;

    //! header data
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

    //! number of columns for a given index
    // virtual int columnCount(const QModelIndex &parent = QModelIndex()) const
    virtual int columnCount(const QModelIndex & = QModelIndex()) const
    { return nColumns; }

    //@}

    public slots:

    //! add macro
    virtual void add( const FtpMacro& macro )
    { ListModel<FtpMacro>::add( macro ); }

    //! add macros
    virtual void add( const FtpMacro::List& macros )
    { ListModel<FtpMacro>::add( macros ); }

    //! remove
    virtual void remove( const FtpMacro& macro )
    { ListModel<FtpMacro>::remove( macro ); }

    //! update configuration
    void updateConfiguration( void );

    protected:

    //! sort
    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder )
    { std::sort( _get().begin(), _get().end(), SortFTor( column, order ) ); }

    private:

    //! used to sort IconCaches
    class SortFTor: public ItemModel::SortFTor
    {

        public:

        //! constructor
        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
            ItemModel::SortFTor( type, order )
        {}

        //! prediction
        bool operator() ( FtpMacro , FtpMacro ) const;

    };

    //! install pixmaps
    void _installIcons( void ) const;

    //! icon from macro type
    static const QIcon& _icon( FtpMacro::Type );

    //! icon cache
    typedef QHash<FtpMacro::Type, QIcon> IconCache;

    static IconCache& _icons( void );

    //! list column names
    static const QString columnTitles_[nColumns];

};

#endif
