// $Id: Menu.cpp,v 1.32 2012/12/17 17:02:18 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Application.h"
#include "Debug.h"
#include "DebugMenu.h"
#include "DockWidget.h"
#include "FileSelectionFrame.h"
#include "LogDialog.h"
#include "MainWindow.h"
#include "Menu.h"
#include "Singleton.h"
#include "Util.h"
#include "ViewModeMenu.h"

//__________________________________________________
Menu::Menu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu" );

    // generic menu
    QMenu *menu;

    Application& application( *Singleton::get().application<Application>() );
    MainWindow& mainwindow( *static_cast<MainWindow*>( window() ) );

    // file menu
    menu = addMenu( "File" );
    menu->addAction( &application.closeAction() );

    // windows menu
    menu = addMenu( "View" );
    menu->addMenu( viewModeMenu_ = new ViewModeMenu( this ) );
    viewModeMenu_->setTitle( "View Mode" );
    menu->addSeparator();
    menu->addAction( &mainwindow.showHiddenFilesAction() );
    menu->addAction( &mainwindow.localSelectionFrame().visibilityAction() );
    menu->addAction( &mainwindow.placesPanel().visibilityAction() );
    menu->addSeparator();
    menu->addAction( &mainwindow.showLogDialogAction() );
    menu->addAction( &mainwindow.showCommandDialogAction() );

    // create Settings menu
    menu = addMenu( "Settings" );
    menu->addAction( &application.configurationAction() );

    // create help menu
    menu = addMenu( "Help" );
    menu->addAction( &application.aboutAction() );
    menu->addAction( &application.aboutQtAction() );

    // debug menu
    #define DEBUG
    #ifdef DEBUG
    menu->addSeparator();
    DebugMenu *debugMenu( new DebugMenu( this ) );
    debugMenu->setTitle( "Debug" );
    menu->addMenu( debugMenu );
    #endif

}
